==> haskell-x509-validation-1.6.3-14-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.3
id: x509-validation-1.6.3-47YgQ3DAMXWHkAIJCZyXbQ
key: x509-validation-1.6.3-47YgQ3DAMXWHkAIJCZyXbQ
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
abi: 37ed5c253c22b905ea8aaf5e11e1c435
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-validation-1.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-validation-1.6.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/x509-validation-1.6.3
hs-libraries: HSx509-validation-1.6.3-47YgQ3DAMXWHkAIJCZyXbQ
depends:
    asn1-encoding-0.9.3-5wnYsJw2Gb51njFqJow1z3
    asn1-types-0.3.2-7OJ0HzVkSNEBIwzF1QvaHd base-4.9.0.0
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.16-E90TQghT3BS5HmJA8qBcdx
    data-default-class-0.1.0-En3KOFJqVML6UJ9gz15quU
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    memory-0.13-9YH63fsEcp4AuUH5L0KHp mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.3-D1Jr3G10xNy9uyPV6jDSS8
    x509-store-1.6.1-GnThW2LhOVPDKGoA94vT8I
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.3-16-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509-validation
version: 1.6.3
id: x509-validation-1.6.3-DBDZJka6xtn5lbGBMQZFGD
key: x509-validation-1.6.3-DBDZJka6xtn5lbGBMQZFGD
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X.509 Certificate and CRL validation
description:
    X.509 Certificate and CRL validation
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509.Validation
hidden-modules: Data.X509.Validation.Signature
                Data.X509.Validation.Fingerprint Data.X509.Validation.Cache
                Data.X509.Validation.Types
abi: 2848d42dbf900e9953243c267f8bca55
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-validation-1.6.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-validation-1.6.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/x509-validation-1.6.3
hs-libraries: HSx509-validation-1.6.3-DBDZJka6xtn5lbGBMQZFGD
depends:
    asn1-encoding-0.9.4-G3Eu427lfih60n7Hu41ILm
    asn1-types-0.3.2-7OJ0HzVkSNEBIwzF1QvaHd base-4.9.0.0
    byteable-0.1.1-15aIBCArSOBEnGxArzrDTM bytestring-0.10.8.1
    containers-0.5.7.1 cryptonite-0.17-KyUY3QlaeIZ9iMNzKLz7fi
    data-default-class-0.1.1-Ly61bORoJc16r3Tjbg7Q3c
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    memory-0.13-9YH63fsEcp4AuUH5L0KHp mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM
    pem-0.2.2-qPMQP6sZm3HgQEmiBojNt x509-1.6.3-KVQlastq3b39uo4k6iTs85
    x509-store-1.6.1-11Z4YEmHXf0m0ASQZjnD2
haddock-interfaces: /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock
haddock-html: /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
